@@ -266,8 +266,9 @@ are ignored. Disabling  extended titles speeds up the processing.
 
 The C<parse> method takes a single parameter of a text string containing a
 name. It attempts to parse the name and break it down into the components
-described above. If the name was parsed successfully, a 0 is returned,
-otherwise a 1. This step is a prerequisite for the following functions.
+
+Returns an error flag, if the name was parsed successfully, it's value is 0,
+otherwise a 1. This step is a prerequisite for the following methods.
 
 
 =head2 case_all
@@ -511,6 +512,11 @@ L<Lingua::EN::NameCase>, L<Parse::RecDescent>
 The dot in a suffix of Jnr. or Snr. will be consumed as unmatched text,
 and not be retained with the suffix.
 
+Names with accented characters (acute, circumfelx etc) will not be parsed
+correctly. A work around is to replace the character class [a-z] with \w
+in the appropriate rules in the grammar tree, but this could lower the accuracy
+of names based purely on ASCII text.
+
 =head1 CREDITS
 
 Thanks to all the people who provided ideas and suggestions, including -
@@ -541,6 +547,7 @@ at your option, any later version of Perl 5 you may have available.
 package Lingua::EN::NameParse;
 
 use strict;
+use warnings;
 
 use Lingua::EN::NameGrammar;
 use Parse::RecDescent;
@@ -548,7 +555,7 @@ use Parse::RecDescent;
 use Exporter;
 use vars qw (@ISA @EXPORT_OK);
 
-our $VERSION   = '1.24';
+our $VERSION   = '1.25';
 @ISA       = qw(Exporter);
 @EXPORT_OK = qw(&clean &case_surname);
 
@@ -587,6 +594,10 @@ sub new
    return ($name);
 }
 #-------------------------------------------------------------------------------
+# Attempt to parse a string and retrieve it's components and properties
+# Requires a name object to have been created with the 'new' method'
+# Returns: an error code, 0 for success, 1 for failure
+
 sub parse
 {
    my $name = shift;
@@ -625,7 +636,7 @@ sub parse
        }
    }
 
-   return($name,$name->{error});
+   return($name->{error});
 }
 #-------------------------------------------------------------------------------
 # Clean the input string. Can be called as a stand alone function.
@@ -647,7 +658,7 @@ sub clean
    return($input_string);
 }
 #-------------------------------------------------------------------------------
-# Return all components in a hash
+# Given a name object, returns all components in a hash
 
 sub components
 {
@@ -662,8 +673,8 @@ sub components
     }
 }
 #-------------------------------------------------------------------------------
-# Apply correct capitalisation to each component of a person's name.
-# Return all cased components in a hash
+# Given a name object, apply correct capitalisation to each component of a
+# person's name. Return all cased components in a hash.
 
 sub case_components
 {
